@@ -1,5 +1,4 @@
-devtools::use_package("devtools")
-# library("devtools")
+usethis::use_package("devtools")
 
 descrip             = readLines("DESCRIPTION")
 spectrolab_version  = tolower(descrip[ grep("Version:", descrip) ])
